@@ -1,13 +1,12 @@
 resource_involvement_case <- function(eventlog) {
 
-	case_classifier <- case_id(eventlog)
-	resource_classifier <- resource_id(eventlog)
+	absolute <- NULL
+	relative <- NULL
 
 	eventlog %>%
-		group_by_(case_classifier, resource_classifier) %>%
+		group_by(!!case_id_(eventlog),  !!resource_id_(eventlog)) %>%
 		summarize() %>%
 		summarize(absolute = n()) %>%
 		mutate(relative = absolute/n_resources(eventlog)) %>%
-		arrange(-absolute) %>%
-		return()
+		arrange(-absolute)
 }
